@@ -22,30 +22,35 @@
  *Free Software Foundation, 
  *Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *
- *Copyright 2001-2002 Dodji SEKETELI, Gal CHAMOULAUD.
- *http://www.freespiders.org
+ *See COPYRIGHT file for copyright information.
  */
 
 #ifndef __MLVIEW_GUI_H__
-#  define __MLVIEW_GUI_H__
-#  include <gnome.h>
-#  include "mlview-editor.h"
+#define __MLVIEW_GUI_H__
 
-#  define MLVIEW_ROOTWINDOW_WIDTH 400
-#  define MLVIEW_ROOTWINDOW_HEIGHT 300
-#  define MLVIEW_MAINPANED_POSITION 400
+#include <libgnomeui/libgnomeui.h>
+#include "mlview-editor.h"
+
+/**
+ *@file 
+ *the mlview application class definition.
+ *It instanciates mlview's instance of  GnomeApp, 
+ *fills it with an instance of MlViewEditor, builds the application menus
+ *and toolbars and creates an instance of MlViewAppContext.
+ */
+
+#define MLVIEW_ROOTWINDOW_WIDTH 400
+#define MLVIEW_ROOTWINDOW_HEIGHT 300
+#define MLVIEW_MAINPANED_POSITION 400
 
 G_BEGIN_DECLS
-        GnomeApp * mlview_app_new (const guchar * a_appname);
+GnomeApp * mlview_app_new (const guchar * a_appname);
 
 MlViewEditor *mlview_app_get_editor (GnomeApp * a_app_name);
 
-void
- mlview_app_set_icon (GnomeApp * a_app_context);
+void mlview_app_set_icon (GnomeApp * a_app_context);
 
-void
- mlview_app_build_set_global_settings (MlViewAppContext * a_app_context);
+void mlview_app_build_set_global_settings (MlViewAppContext * a_app_context);
 
 G_END_DECLS
 #endif
